Learn R Programming

openaiRtools (version 0.2.2)

AudioTranslationsClient: Audio Translations Client

Description

Translates audio from any supported language into English text using Whisper. Access via client$audio$translations.

Arguments

Methods


Method new()

Usage

AudioTranslationsClient$new(parent)


Method create()

Usage

AudioTranslationsClient$create(
  file,
  model = "whisper-1",
  prompt = NULL,
  response_format = NULL,
  temperature = NULL
)


Method clone()

The objects of this class are cloneable with this method.

Usage

AudioTranslationsClient$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.