Learn R Programming

openaiRtools (version 0.2.2)

RunStepsClient: Run Steps Client

Description

Lists and retrieves the individual steps taken during a run. Each run may consist of multiple steps (e.g. thinking, tool calls, message creation). Access via client$threads$runs$steps.

Arguments

Methods


Method new()

Usage

RunStepsClient$new(parent)


Method list()

Usage

RunStepsClient$list(
  thread_id,
  run_id,
  limit = NULL,
  order = NULL,
  after = NULL,
  before = NULL
)


Method retrieve()

Usage

RunStepsClient$retrieve(thread_id, run_id, step_id)


Method clone()

The objects of this class are cloneable with this method.

Usage

RunStepsClient$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.