Learn R Programming

openaiRtools (version 0.2.2)

VectorStoreFileBatchesClient: Vector Store File Batches Client

Description

Add multiple files to a vector store in a single batch operation. More efficient than adding files one-by-one when loading many files. Access via client$vector_stores$file_batches.

Arguments

Methods


Method new()

Usage

VectorStoreFileBatchesClient$new(parent)


Method create()

Usage

VectorStoreFileBatchesClient$create(
  vector_store_id,
  file_ids,
  chunking_strategy = NULL
)


Method retrieve()

Usage

VectorStoreFileBatchesClient$retrieve(vector_store_id, batch_id)


Method cancel()

Usage

VectorStoreFileBatchesClient$cancel(vector_store_id, batch_id)


Method list_files()

Usage

VectorStoreFileBatchesClient$list_files(
  vector_store_id,
  batch_id,
  limit = NULL,
  order = NULL,
  after = NULL,
  before = NULL
)


Method clone()

The objects of this class are cloneable with this method.

Usage

VectorStoreFileBatchesClient$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.