Translates audio from any supported language into English text using
Whisper. Access via client$audio$translations.
new()AudioTranslationsClient$new(parent)
create()AudioTranslationsClient$create(
file,
model = "whisper-1",
prompt = NULL,
response_format = NULL,
temperature = NULL
)
clone()The objects of this class are cloneable with this method.
AudioTranslationsClient$clone(deep = FALSE)deepWhether to make a deep clone.