Provides methods to create, manage and retrieve chat completions.
Access via client$chat$completions.
new()ChatCompletionsClient$new(parent)
create()ChatCompletionsClient$create(
messages,
model = "gpt-3.5-turbo",
frequency_penalty = NULL,
logit_bias = NULL,
logprobs = NULL,
top_logprobs = NULL,
max_tokens = NULL,
max_completion_tokens = NULL,
n = NULL,
presence_penalty = NULL,
response_format = NULL,
seed = NULL,
stop = NULL,
stream = NULL,
stream_options = NULL,
temperature = NULL,
top_p = NULL,
tools = NULL,
tool_choice = NULL,
parallel_tool_calls = NULL,
user = NULL,
store = NULL,
metadata = NULL,
callback = NULL,
...
)
retrieve()ChatCompletionsClient$retrieve(completion_id)
update()ChatCompletionsClient$update(completion_id, metadata = NULL)
list()ChatCompletionsClient$list(
model = NULL,
after = NULL,
limit = NULL,
order = NULL,
metadata = NULL
)
delete()ChatCompletionsClient$delete(completion_id)
clone()The objects of this class are cloneable with this method.
ChatCompletionsClient$clone(deep = FALSE)deepWhether to make a deep clone.