Provides text embedding (vectorization) via the OpenAI Embeddings API.
Access via client$embeddings.
new()EmbeddingsClient$new(parent)
create()EmbeddingsClient$create(
input,
model = "text-embedding-ada-002",
encoding_format = NULL,
dimensions = NULL,
user = NULL
)
clone()The objects of this class are cloneable with this method.
EmbeddingsClient$clone(deep = FALSE)deepWhether to make a deep clone.
Embeddings are numerical vector representations of text that capture semantic meaning. Similar texts produce similar vectors. Common uses include semantic search, clustering, classification, and recommendation systems.