Lists and retrieves the individual steps taken during a run.
Each run may consist of multiple steps (e.g. thinking, tool calls,
message creation). Access via client$threads$runs$steps.
new()RunStepsClient$new(parent)
list()RunStepsClient$list(
thread_id,
run_id,
limit = NULL,
order = NULL,
after = NULL,
before = NULL
)
retrieve()RunStepsClient$retrieve(thread_id, run_id, step_id)
clone()The objects of this class are cloneable with this method.
RunStepsClient$clone(deep = FALSE)deepWhether to make a deep clone.