Add multiple files to a vector store in a single batch operation.
More efficient than adding files one-by-one when loading many files.
Access via client$vector_stores$file_batches.
new()VectorStoreFileBatchesClient$new(parent)
create()VectorStoreFileBatchesClient$create(
vector_store_id,
file_ids,
chunking_strategy = NULL
)
retrieve()VectorStoreFileBatchesClient$retrieve(vector_store_id, batch_id)
cancel()VectorStoreFileBatchesClient$cancel(vector_store_id, batch_id)
list_files()VectorStoreFileBatchesClient$list_files(
vector_store_id,
batch_id,
limit = NULL,
order = NULL,
after = NULL,
before = NULL
)
clone()The objects of this class are cloneable with this method.
VectorStoreFileBatchesClient$clone(deep = FALSE)deepWhether to make a deep clone.